##########################################################################
# zopyx.convert - XSL-FO related functionalities
#
# (C) 2007, ZOPYX Ltd & Co. KG, Tuebingen, Germany
##########################################################################

java = 'java'
supported_formats = ('pdf', 'pdf2', 'rtf', 'wml', 'docx', 'odt')
